@@ -1,5 +1,8 @@
+"""This module handles the conversion of data structures
+between R objects handled by rpy2 and pandas objects."""
+
 import os
-import pytz
+import dateutil.tz
 from datetime import datetime
 import rpy2.robjects as ro
 import rpy2.robjects.conversion as conversion
@@ -15,6 +18,8 @@ from pandas.core.index import Index as PandasIndex
 import pandas
 from numpy import recarray
 import numpy
+import pytz
+import tzlocal
 import warnings
 
 from collections import OrderedDict
@@ -34,7 +39,6 @@ original_converter = None
 # activate in the function activate() below
 import rpy2.robjects.numpy2ri as numpy2ri
 
-
 ISOdatetime = rinterface.baseenv['ISOdatetime']
 as_vector = rinterface.baseenv['as.vector']
 
@@ -48,6 +52,8 @@ ri2ro = converter.ri2ro
 dt_datetime64ns_type = numpy.dtype('datetime64[ns]')
 dt_O_type = numpy.dtype('O')
 
+default_timezone = None
+
 @py2ri.register(PandasDataFrame)
 def py2ri_pandasdataframe(obj):
     od = OrderedDict()
@@ -146,20 +152,10 @@ def ri2py_intvector(obj):
 
 def get_timezone():
     """ Return the system's timezone settings. """
-    etc_timezone = '/etc/timezone'
-    timezone = pytz.timezone('UTC')
-    if os.path.exists(etc_timezone):
-        try:
-            with open(etc_timezone) as fh:
-                tz = fh.read().strip()
-            try :
-                timezone = pytz.timezone(tz)
-            except pytz.UnknownTimeZoneError:
-                warnings.warn('Unknown time zone in %s, using UTC.' % etc_timezone)
-        except IOError:
-            warnings.warn('Unable to read date in %s, using UTC.' % etc_timezone)
+    if default_timezone:
+        timezone = default_timezone
     else:
-        warnings.warn('No file %s' % etc_timezone)
+        timezone = tzlocal.get_localzone()
     return timezone
 
 
